@@ -5,6 +5,8 @@ from abc import abstractmethod, ABC
 from enum import IntEnum
 from typing import List, Optional
 
+from pykotor.extract.file import ResourceIdentifier
+
 from pykotor.common.geometry import Vector2, Vector3, Vector4, Polygon3
 from pykotor.common.language import LocalizedString
 from pykotor.common.misc import Game, Color, ResRef
@@ -188,15 +190,9 @@ class GITInstance(ABC):
         self.position: Vector3 = Vector3(x, y, z)
 
     @abstractmethod
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        ...
-
-    @abstractmethod
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
+    ) -> Optional[ResourceIdentifier]:
         ...
 
     @abstractmethod
@@ -229,6 +225,13 @@ class GITInstance(ABC):
     ) -> str:
         ...
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        """
+        Returns the yaw rotation (in radians) of the instance if the instance supports it, otherwise returns None.
+        """
+
 
 class GITCamera(GITInstance):
     GFF_STRUCT_ID = 14
@@ -237,15 +240,19 @@ class GITCamera(GITInstance):
             self,
             x: float = 0.0,
             y: float = 0.0,
-            z: float = 0.0
+            z: float = 0.0,
+            yaw: float = 0.0,
+            pitch: float = 0.0,
+            roll: float = 0.0,
+            camera_id: int = 0
     ):
         super().__init__(x, y, z)
-        self.camera_id = 0
-        self.fov: float = 0
+        self.camera_id = camera_id
+        self.fov: float = 45
         self.height: float = 0.0
         self.mic_range: float = 0.0
         self.pitch: float = 0.0
-        self.orientation: Vector4 = Vector4.from_null()
+        self.orientation: Vector4 = Vector4.from_euler(math.pi/2-yaw, roll, math.pi-pitch)
 
     def move(
             self,
@@ -263,11 +270,15 @@ class GITCamera(GITInstance):
             pitch: float,
             roll: float
     ) -> None:
-        ...
+        rotation = self.orientation.to_euler()
+        rotation.x += pitch
+        rotation.y += roll
+        rotation.z += yaw
+        self.orientation = Vector4.from_euler(rotation.x, rotation.y, rotation.z)
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
+    ) -> Optional[ResourceIdentifier]:
         return None
 
     def blank(
@@ -275,16 +286,16 @@ class GITCamera(GITInstance):
     ) -> Optional[bytes]:
         return None
 
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return None
-
     def classification(
             self
     ) -> str:
         return "Camera"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.orientation.to_euler().z
+
 
 class GITCreature(GITInstance):
     GFF_STRUCT_ID = 4
@@ -317,10 +328,10 @@ class GITCreature(GITInstance):
     ) -> None:
         self.bearing += yaw
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTC)
 
     def blank(
             self
@@ -337,6 +348,11 @@ class GITCreature(GITInstance):
     ) -> str:
         return "Creature"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.bearing
+
 
 class GITModuleLink(IntEnum):
     NoLink = 0
@@ -356,7 +372,7 @@ class GITDoor(GITInstance):
         super().__init__(x, y, z)
         self.resref: ResRef = ResRef.from_blank()
         self.bearing: float = 0.0
-        self.tweak_color: Optional[Color] = Color.WHITE
+        self.tweak_color: Optional[Color] = None
         self.linked_to: str = ""
         self.linked_to_flags: GITModuleLink = GITModuleLink.NoLink
         self.linked_to_module: ResRef = ResRef.from_blank()
@@ -386,21 +402,21 @@ class GITDoor(GITInstance):
     ) -> Optional[bytes]:
         return bytes_utd(UTD())
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
-
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTD
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTD)
 
     def classification(
             self
     ) -> str:
         return "Door"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.bearing
+
 
 class GITEncounterSpawnPoint:
     def __init__(
@@ -449,26 +465,26 @@ class GITEncounter(GITInstance):
     ) -> None:
         raise ValueError("Encounters cannot be rotated.")
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTE)
 
     def blank(
             self
     ) -> Optional[bytes]:
         return bytes_ute(UTE())
 
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTE
-
     def classification(
             self
     ) -> str:
         return "Encounter"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return None
+
 
 class GITPlaceable(GITInstance):
     GFF_STRUCT_ID = 9
@@ -482,7 +498,7 @@ class GITPlaceable(GITInstance):
         super().__init__(x, y, z)
         self.resref: ResRef = ResRef.from_blank()
         self.bearing: float = 0.0
-        self.tweak_color: Optional[Color] = Color.WHITE
+        self.tweak_color: Optional[Color] = None
 
     def move(
             self,
@@ -502,26 +518,26 @@ class GITPlaceable(GITInstance):
     ) -> None:
         self.bearing += yaw
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTP)
 
     def blank(
             self
     ) -> Optional[bytes]:
         return bytes_utp(UTP())
 
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTP
-
     def classification(
             self
     ) -> str:
         return "Placeable"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.bearing
+
 
 class GITSound(GITInstance):
     GFF_STRUCT_ID = 6
@@ -553,15 +569,10 @@ class GITSound(GITInstance):
     ) -> None:
         raise ValueError("Sounds cannot be rotated.")
 
-    def extension(
+    def identifier(
             self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTS
-
-    def reference(
-            self
-    ) -> Optional[ResRef]:
-        return self.resref
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTS)
 
     def blank(
             self
@@ -573,6 +584,11 @@ class GITSound(GITInstance):
     ) -> str:
         return "Sound"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return None
+
 
 class GITStore(GITInstance):
     GFF_STRUCT_ID = 11
@@ -605,15 +621,10 @@ class GITStore(GITInstance):
     ) -> None:
         self.bearing += yaw
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
-    
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTM
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTM)
 
     def blank(
             self
@@ -625,6 +636,11 @@ class GITStore(GITInstance):
     ) -> str:
         return "Store"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.bearing
+
 
 class GITTrigger(GITInstance):
     GFF_STRUCT_ID = 1
@@ -663,15 +679,10 @@ class GITTrigger(GITInstance):
     ) -> None:
         raise ValueError("Triggers cannot be rotated.")
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
-
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTT
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTT)
 
     def blank(
             self
@@ -683,6 +694,11 @@ class GITTrigger(GITInstance):
     ) -> str:
         return "Trigger"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return None
+
 
 class GITTransitionTrigger(GITTrigger):
     def __init__(
@@ -732,15 +748,10 @@ class GITWaypoint(GITInstance):
     ) -> None:
         self.bearing += yaw
 
-    def reference(
+    def identifier(
             self
-    ) -> Optional[ResRef]:
-        return self.resref
-
-    def extension(
-            self
-    ) -> Optional[ResourceType]:
-        return ResourceType.UTW
+    ) -> Optional[ResourceIdentifier]:
+        return ResourceIdentifier(self.resref.get(), ResourceType.UTW)
 
     def blank(
             self
@@ -752,6 +763,11 @@ class GITWaypoint(GITInstance):
     ) -> str:
         return "Waypoint"
 
+    def yaw(
+            self
+    ) -> Optional[float]:
+        return self.bearing
+
 
 def construct_git(
         gff: GFF
@@ -921,8 +937,11 @@ def dismantle_git(
     properties_struct = root.set_struct("AreaProperties", GFFStruct())
     properties_struct.set_int32("AmbientSndDayVol", git.ambient_volume)
     properties_struct.set_int32("AmbientSndDay", git.ambient_sound_id)
+    properties_struct.set_int32("AmbientSndNitVol", git.ambient_volume)
+    properties_struct.set_int32("AmbientSndNight", git.ambient_sound_id)
     properties_struct.set_int32("EnvAudio", git.env_audio)
-    properties_struct.set_uint32("MusicDay", git.music_standard_id)
+    properties_struct.set_int32("MusicDay", git.music_standard_id)
+    properties_struct.set_int32("MusicNight", git.music_standard_id)
     properties_struct.set_int32("MusicBattle", git.music_battle_id)
     properties_struct.set_int32("MusicDelay", git.music_delay)
 
